/***************************************************************************
* Titel        : CT05.C
*
* Description  : UEXC for MSP430 
*
* Environment  : ICC430 V6.05, MSP430F149
*
* Responsible  : J. Altenburg
*
* Guidelines   :
*
* Revision List:
  --------------------------------------------------------------------------
  Date     | Author          | Change
  --------------------------------------------------------------------------
  12.02.04 |J. Altenburg     | first release
  --------------------------------------------------------------------------
           |                 |
  --------------------------------------------------------------------------
****************************************************************************/

/***************************************************************************
* HEADER-FILES (Only those that are needed in this file)                   *
****************************************************************************/
/* System-headerfiles */
#include "cdef.h"      			/* General definitions and types */
#include "msp430x14x.h"         /* MSP430 definitions */
#include "msp430def.h"          

/* Own headerfiles */	


/* Foreign headerfiles */
#include "uexec.h"

/***************************************************************************
* Defines und Makros 
****************************************************************************/

/***************************************************************************
*    Local Function Prototypes
****************************************************************************/
typedef void (* fLocalFunc)( void );    /* function pointer */


/***************************************************************************
*    Global Variables
****************************************************************************/
struct stTimer{
     word Run  : 1;         /* enable, disable scheduling */
     word F1   : 1;         /* timer flag */
     } stTimer;

word wTaskId0; /*
* Description : Task-ID #0
*/

word wTaskId1; /*
* Description : Task-ID #1
*/

word wTaskId2; /*
* Descrition  : Task-ID #2
*/

word wRegister; /*
* Description : temporaray CPU help register
*/

byte abTask0[UEXC_MIN_STACK_SIZE]; /*
* Description : Memory area for task 0
*/

byte abTask1[UEXC_MIN_STACK_SIZE]; /*
* Description : Memory area for task 1
*/


byte abTask2[UEXC_MIN_STACK_SIZE]; /*
* Description : Memory area for task 2
*/


/***************************************************************************
*    Code Area
****************************************************************************/
void vTask2( void ){		    /* example for task 2 */
    word w;
    byte i;
    for(i = 0; i < 8; i++){
        w = 30000;
        while(w--);
        P2OUT ^= 0x04;	        /* pin P2.3 toggles */
	    }
    }

void vTask0( void ){		    /* example for task 0 */
    word w;
	while(1){
	    w = 60000;
		while(w--);
        P2OUT ^= 0x01;	        /* pin P2.0 toggles */
		}
    }

void vTask1( void ){		    /* example for task 1 */
    dword dw;
	while(1){
	    dw = 80000;
		while(dw--);
		P2OUT ^= 0x02; 	        /* pin P2.1 toggles */
        wTaskId2 = UEXC_CreateTask(vTask2, &abTask2[0], sizeof (abTask2), 1);	   
		}
    }

   

/***************************************************************************
*    Function: 	Hardware Initialisation
*                             
*    Author:    Jens Altenburg 
****************************************************************************/
/* Oszillator 8MHz Crystal */
void vClockInit( void ){
    word w;
    WDTCTL = WDTPW + WDTHOLD;       /* Watchdog disable */
#if 1 /* only for testing purposes */
    P5DIR |= 0x10;                  /* 8MHz-CLK to pin 48 */
    P5SEL |= 0x10;
    P5DIR |= 0x20;                  /* SMCLK to pin 49 */
    P5SEL |= 0x20;
#endif
    BCSCTL1 &= ~XT2OFF;             /* Oszillator on */
    do  {	 					    /* checks if 8MHz - crystal runs */
         IFG1 &= ~OFIFG;
         for(w = 0xff; w > 0; w--);
         }
    while((IFG1 & OFIFG) != 0);
    BCSCTL2 = 0x88;
//     BCSCTL2 |= SELM1 + SELS + DIVS0;  
    }

/* I/O Ports */
void vPortInit( void ){
    P1OUT   = 0x00;                 /* all output, no interrupt */
    P1DIR   = 0x7F;
    P1IES   = 0x00;
    P1IE    = 0x00;
    P1SEL   = 0x00;
    P2OUT   = 0xFF;                 /* all output LED on pin 0...2       */
    P2DIR   = 0xFF;                 /*       ----    | /|                */
    P2IES   = 0x00;                 /*  o---|    |---|< |---o Vcc (3.3V) */
    P2IE    = 0x00;                 /*       ----    | \| LED            */
    P2SEL   = 0x00;                 /*  Pin 0...2                        */

    P3OUT   = 0x00;                 /* UART0, P3.4 output */
    P3DIR   = 0x10;
    P3SEL   = 0x30;

    P4OUT   = 0xFE;                 /* CFG - Port */
    P4DIR   = 0x7f;
    P4SEL   = 0x00;
#if 0
    P5OUT   = 0x00;                 /* not used */
    P5DIR   = 0x00;
    P5SEL   = 0x00;
#endif
    P6OUT   = 0x00;                 /* not used */
    P6DIR   = 0x00;
    P6SEL   = 0x03;                 /* A/D-converter, not used */
    }

/* Timer A, triggers Scheduler */
void vTimeraInit( void ){
    TACTL = TASSEL1 + TACLR;        /* SMCLK, clear TAR */
    CCTL0 = CCIE;                   /* CCR0 interrupt enable */
    CCR0 = 10000;                   /* 2,5 ms Timer Click */
    TACTL |= MC0;                   /* Up-Mode */
    }


/* call this routine to initialise all peripherals */
void vInitDevices( void ){
    DINT();                         /* disable all interrupts */
//   ME1     = 0x00;                /* disable sfr peripherals */
//   ME2     = 0x00;                /* disable sfr peripherals */
//   IE1     = 0x00;                /* disable sfr interrupts */
//   IE2     = 0x00;                /* disable sfr interrupts */

//   WDTCTL  = 0x5A | 0x15;         /* watchdog initialisation including nmi function */

    vClockInit();                   /* initialise other peripherals */
    vPortInit();
//     vTimeraInit();			    /* was made by UEXEC */

//   ME1     = 0xC0;                /* enable sfr peripherals */
//   ME2     = 0x00;                /* enable sfr peripherals */
//   IE1     = 0xC0;                /* enable sfr interrupts */
//   IE2     = 0x03;                /* disable sfr interrupts */
//   EINT();                        /* re-enable interrupts */
    }


/***************************************************************************
* Function  : Main-Loop
*		      - initialises peripherals
*			  - create tasks, start scheduler
*                             
* Author    : Jens Altenburg 
****************************************************************************/
int main(void){
    vInitDevices();
    wTaskId0 = UEXC_CreateTask(vTask0, &abTask0[0], sizeof (abTask0), 1);
    wTaskId1 = UEXC_CreateTask(vTask1, &abTask1[0], sizeof (abTask1), 1);
    UEXC_StartScheduler();
    return 1;                       /* avoid compiler warning */
    }

/***************************************************************************
* Function  : timer controls cyclic scheduler call
* Author    : Jens Altenburg
****************************************************************************/
#pragma interrupt_handler timera_0_isr:TIMERA0_VECTOR
void timera_0_isr(void){
    CCR0 = 20000;                   /* 2,5 ms time slot */
	P2OUT ^= 0x80;                  /* for diagnostic */
asm(
	" push  r4\n"                   /* save CPU register */    
	" push  r5\n"
	" push  r6\n"
	" push  r7\n"
	" push  r8\n"
	" push  r9\n"
	" push  r10\n"
	" push  r11\n"
	" push  r12\n"
	" push  r13\n"
	" push  r14\n"
	" push  r15\n"
	" mov 	SP,%uexc_current_sp\n"  /* save stackpointer */
   	" call	#%UEXC_CheckTask\n"		/* check task state */
	" pop   r15\n"                  /* restore register */
	" pop   r14\n"
	" pop   r13\n"
	" pop   r12\n"
	" pop   r11\n"
	" pop   r10\n"
	" pop   r9\n"
	" pop   r8\n"
	" pop   r7\n"
	" pop   r6\n"
	" pop   r5\n"
	" pop   r4\n"
	" reti\n");
	}

/***************************************************************************
* Function  : starts timer
* Author    : Jens Altenburg
****************************************************************************/
void UEXC_StartTimer(void){
    vTimeraInit();
    EINT();	                        /* Scheduler enables interrupts */
	}


/***************************************************************************
* Function  : save state and then reschedule this called by Defer 
*             to give up control
* Author    : Jens Altenburg
****************************************************************************/
void UEXC_SavregsAndResched(void){
asm(
	" mov     SR,%wRegister\n"           /* interrupt stack frame */
	" bis     #8,%wRegister\n"		 	 /* enable GIE */
	" push.w  %wRegister\n"				 /* "SR" to stack */
	" push  r4\n"
	" push  r5\n"
	" push  r6\n"
	" push  r7\n"
	" push  r8\n"
	" push  r9\n"
	" push  r10\n"
	" push  r11\n"
	" push  r12\n"
	" push  r13\n"
	" push  r14\n"
	" push  r15\n"
	" mov.w   r15,%wRegister\n"			 /* r15 for indexed adressing */
	" mov.w   %uexc_current_sp,r15\n"
	" mov.w	  SP,(r15)\n"	 		 	 /* save stackpointer */
	" mov.w	  %wRegister,r15\n"
	" br	  #%UEXC_Schedule\n"		 /* Schedule */
	);
    }

/***************************************************************************
* Function  : start a new task
* Author    : Jens Altenburg
****************************************************************************/
void UEXC_StartNewTask(void){
asm(
	" mov     %uexc_current_sp, SP\n"	 /* moves content of uexc_cu.. to SP */
	" push.w  #%UEXC_KillSelf\n" 		 /* Killself() onto stack */
	" push.w  %uexc_current_func\n"	 	 /* new function to stack */
	" mov	  SR,%wRegister\n"		 	 /* Statusregister bearbeiten */
	" bis	  #8,%wRegister\n"		 	 /* GIE */
	" push.w  %wRegister\n"			 	 /* statusregister to stack */
	" reti\n"						 	 /* go */
	);	 
    }

/***************************************************************************
* Function  : Resume a previously stopped task
* Author    : Jens Altenburg
****************************************************************************/
void UEXC_Resume(void){
asm(
	" mov     %uexc_current_sp, SP\n"    /* set Stackpointer */
	" pop   r15\n"
	" pop   r14\n"
	" pop   r13\n"
	" pop   r12\n"
	" pop   r11\n"
	" pop   r10\n"
	" pop   r9\n"
	" pop   r8\n"
	" pop   r7\n"
	" pop   r6\n"
	" pop   r5\n"
	" pop   r4\n"
	" reti\n"				  		   	 /* ... */
	);
    }


/***************************************************************************
* EOF: CT05.C
****************************************************************************/

