/***************************************************************************
* Titel        : NAVI.C
*
* Description  : Navigations-Task
*
* Environment  : ICC430 V6.05, MSP430F149
*
* Responsible  : J. Altenburg
*
* Guidelines   :
*
* Revision List:
  --------------------------------------------------------------------------
  Date     | Author          | Change
  --------------------------------------------------------------------------
  12.02.04 |J. Altenburg     | first release
  --------------------------------------------------------------------------
           |                 |
  --------------------------------------------------------------------------
****************************************************************************/

/***************************************************************************
* HEADER-FILES (Only those that are needed in this file)                   *
****************************************************************************/
/* System-headerfiles */
#include "cdef.h"                  /* General definitions and types */
#include "msp430x14x.h"         /* MSP430 definitions */
#include "msp430def.h"

/* Own headerfiles */
#include "navi.h"

/* Foreign headerfiles */
#include "smd.h"
#include "i2c.h"

/***************************************************************************
* Defines und Makros
****************************************************************************/

/***************************************************************************
*    Local Function Prototypes
****************************************************************************/
typedef void (* fLocalFunc)( void );    /* function pointer */

#define nLeftBit    0x01
#define nRightBit   0x02
#define nFullStep   0x00

/***************************************************************************
*    Global Variables
****************************************************************************/
byte bIndexToJob; /*
* Description : gerade laufender Job
*/

byte bIndexToNextJob; /*
* Description : nchster Job in der Liste
*/

NAVI_stJob stJobList[nJobListSize + 1]; /*
* Description : Jobliste
*/

byte bJobState; /*
* Description : Aktivitt eines Jobs
*/

NAVI_stJob stJob; /*
* Description : Jobdaten 
*/

/***************************************************************************
*    Code Area
****************************************************************************/
/***************************************************************************
*    Function:  NAVI-Init
*
*    Author:    Jens Altenburg
****************************************************************************/
void NAVI_vInit( void ){
    bIndexToJob = bIndexToNextJob = 0;
    bJobState = 0;
    }

/***************************************************************************
*    Function:  Callback-Left
*
*    Author:    Jens Altenburg
****************************************************************************/
void vCallbackLeft( void ){
    bJobState &= ~nLeftBit; /* Schrittmotor Links fertig */
    }

/***************************************************************************
*    Function:  Callback-Right
*
*    Author:    Jens Altenburg
****************************************************************************/
void vCallbackRight( void ){
    bJobState &= ~nRightBit; /* rechts fertig */
    }

/***************************************************************************
*    Function:  trgt einen neuen Job in Liste ein (wenn Platz ist)
*
*    Author:    Jens Altenburg
****************************************************************************/
byte NAVI_bNewJob (NAVI_stJob *stJob){
    byte i, j;
    i = bIndexToNextJob;
    i++;                    /* Zeiger erhhen */
    i &= nJobListSize;      /* auf richtige Gre maskieren */
    j = bIndexToJob & nJobListSize; /* dito. fr den anderen Zeiger */
    if(i == j){
        return False;       /* Liste voll */
        }
    else{
        stJobList[i] = *stJob; /* Job eintragen */
        bIndexToNextJob++;
        return True;        /* erledigt */
        }
    }

/***************************************************************************
*    Function:  NAVI-Task
*    Author:    Jens Altenburg
****************************************************************************/
void NAVI_vMain( void ){
    dword dw;
    word  wS; /* Geschwindigkeit */
    int32 iS; /* Schritte */
    while(1){
#if 1
        P5OUT ^= 0x02;
        if(bIndexToJob != bIndexToNextJob){
            bIndexToJob++;
            stJob = stJobList[bIndexToJob & nJobListSize];
            bJobState = nLeftBit + nRightBit;   /* Job aktiv */
            switch(stJob.enType){
                case enRobS:                    /* Stop */
                    SMD_vStartL(vCallbackLeft,  nFullStep, stJob.wSpeed, 0);
                    SMD_vStartR(vCallbackRight, nFullStep, stJob.wSpeed, 0);
                    I2C_vState(1);
                    break;
                case enRobF:                    /* Robot Forward */
                    SMD_vStartL(vCallbackLeft,  nFullStep, stJob.wSpeed, stJob.iSteps);
                    SMD_vStartR(vCallbackRight, nFullStep, stJob.wSpeed, stJob.iSteps);
                    I2C_vState(2);
                    break;
                case enRobB:                    /* Robot Bachward */
                    SMD_vStartL(vCallbackLeft,  nFullStep, stJob.wSpeed, stJob.iSteps * -1);
                    SMD_vStartR(vCallbackRight, nFullStep, stJob.wSpeed, stJob.iSteps * -1);
                    I2C_vState(3);
                    break;
                case enRobL:                    /* Robot Left */
                    SMD_vStartL(vCallbackLeft,  nFullStep, stJob.wSpeed, stJob.iSteps * -1);
                    SMD_vStartR(vCallbackRight, nFullStep, stJob.wSpeed, stJob.iSteps);
                    I2C_vState(4);
                    break;
                case enRobR:                    /* Robot Right */
                    SMD_vStartL(vCallbackLeft,  nFullStep, stJob.wSpeed, stJob.iSteps);
                    SMD_vStartR(vCallbackRight, nFullStep, stJob.wSpeed, stJob.iSteps * -1);
                    I2C_vState(5);
                    break;
                case enRobBl:                   /* Bogen links */
                    SMD_vStartL(vCallbackLeft,  nFullStep, 25500, 1370);
                    SMD_vStartR(vCallbackRight, nFullStep, 15000, 2340);
                    I2C_vState(6);
                    break;
                case enRobBr:                   /* Bogen rechts */
                    SMD_vStartL(vCallbackLeft,  nFullStep, 15000, 2340);
                    SMD_vStartR(vCallbackRight, nFullStep, 25500, 1370);
                    I2C_vState(7);
                    break;
                default:
                    bJobState = 0;
                    break;
                }
            while(bJobState);                   /* ich haben fertig */
            dw = 1000;                         /* have a break, have a ... */
            while(dw--); 
            }
#else
            //DINT(); 
            SMD_vStartL(vCallbackLeft,  nFullStep, 35000,  -120);
            SMD_vStartR(vCallbackRight, nFullStep, 35000,  120);
            //EINT();
            bJobState = nRightBit + nLeftBit; 
            while(bJobState);
            dw = 80000;
            while(dw--); 
#endif
        }
    }


/***************************************************************************
* EOF: NAVI.C
****************************************************************************/

