/***************************************************************************
* Titel        : RF4.C
*
* Description  : Ansteuerung fr nRF903, 433MHz
*
* Environment  :
*
* Responsible  : J. Altenburg
*
* Guidelines   :
*
* Revision List:
  --------------------------------------------------------------------------
  Date     | Author          | Change
  --------------------------------------------------------------------------
  10.06.03 |J. Altenburg     | Ersterstellung
  --------------------------------------------------------------------------
           |                 |
  --------------------------------------------------------------------------
****************************************************************************/

/***************************************************************************
* HEADER-FILES (Only those that are needed in this file)                   *
****************************************************************************/
/* System-headerfiles */
#include "cdef.h"                      /* General definitions and types */

/* Own headerfiles */
#include "rf433.h"

/* Foreign headerfiles */

/***************************************************************************
*    Variablen                                                             *
****************************************************************************/
byte bRfState; /*
* Description : Variable fr Zustandsautomat
*/

byte bTimeout; /*
* Description : Timeoutzhler
*/

fCallBackRx fRxFunc; /*
* Description : Callbackfunktion fr Rx-Interruptservice
*/

byte *pTxBuffer; /*
* Description : Zeiger auf Sendepuffer
*/

byte bTxIndex; /*
* Description : Anzahl der zu sendenden Zeichen
*/

enTxState enState; /*
* Description : Zustand der Senderoutine
*/

byte bSyncCount; /*
* Description : Sync-Zeichenzhler
*/

byte bTxState; /*
* Description : Zustandsautomat Tx-ISR
*/

/* Zugriffsmakros fr Merkflags */

/***************************************************************************
* Defines und Makros Zugriff                                               *
****************************************************************************/
#define nDefault433      0xf000    /* Defaultwert fr Configurationswort */
#define nMaxChannel      9         /* Anzahl der HF-Kanle */
#define nOneSecond       100       /* eine Sekunde */

#define vRxLedOn()       (P2OUT &= ~0x40)
#define vRxLedOff()      (P2OUT |=  0x40)
#define vTxLedOn()       (P2OUT &= ~0x80)
#define vTxLedOff()      (P2OUT |=  0x80)

#define nSync            0xCC      /* Sync-Zeichen */
#define nSyncEnd         0xF0      /* letztes Sync-Zeichen */
#define nSyncTime        76        /* 76 x 0xcc = 10 ms (76,2 kBaud) */

enum {
     enRfInit = 0,                 /* tut nix */
     enRfCheckCarrier,             /* Test auf Trger */
     enRfPrepareRx,                /* Empfangsmode vorbereiten */
     enRfReceive,                  /* Empfangsmode */
     enRfPrepareTx,                /* Sendemode vorbereiten */
     enRfTransmit                  /* Senden */
     };

enum {
     enTxSync = 0,                 /* TX-ISR sendet Sync-Zeichen */
     enTxSyncEnd,
     enTxMessage,                  /* Botschaft wird gesendet */
     enTxOff                       /* Tx-ISR beenden */
     };

/***************************************************************************
*    Code                                                                  *
****************************************************************************/

/***************************************************************************
*    Funktion: Dummy fr Empfangsroutine                                   *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void vRxDummy( byte i ){
      i++;        /* */
      }

/***************************************************************************
*    Funktion: schickt die Configurationsdaten zum nRF903                  *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void vSendCfg(word wCfg){
     byte i;
     CFG_CS(1);                              /* CFG-Mode enabled */
     for(i = 15; i > 1; i--){
          CFG_CLK(0);
          if(wCfg & (1 << i)){               /* Datenbit setzen */
               CFG_DATA(1);
               }
          else CFG_DATA(0);
          CFG_CLK(1);                        /* einschieben */
          }
     i++;                                    /* Dummy-Code, kurze Zeit */
     CFG_CLK(0);
     CFG_CS(0);                              /* CFG-Mode disable */
     }

/***************************************************************************
*    Funktion: Initialisiert enState                                       *
*                                                                          *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void RF4_vClearState( void ){
     enState = enTxReady;
     }

/***************************************************************************
*    Funktion: Initialisierung                                             *
*                                                                          *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void RF4_vInit( void ){
     bTxIndex = 0;
     fRxFunc = vRxDummy;                     /* Callbackfunktion initialisieren */
     /* UART einstellen 76,2 kBaud */
     U0CTL   = CHAR;                         /* 8-Bit Zeichen */
     U0TCTL  = SSEL1;                        /* UCLK = SMCLK */
//   URCTL0  = URXEIE;                       /* Empfangsinterrupt */
     U0BR0   = 0x69;
     U0BR1   = 0x00;
//   UMCTL0  = 0x00;
     ME1 |= UTXE0 + URXE0; /* UART0 enable */
     bRfState = enRfInit;
     enState = enTxReady;
     }

/***************************************************************************
*    Funktion: Kommunikationsinterface zum RF-Modul ffnen                 *
*              es wird automatisch versucht empfangswrdige Zeichen        *
*              an die Callbackfunktion zu bergeben, d.h. der Empfnger    *
*              ist aktiv                                                   *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
bool RF4_boOpen ( fCallBackRx fRx, byte bChannel ){
     word wCfgData = nDefault433;
     if(fRxFunc == vRxDummy){
          STBY(0);                 /* Einschalten des nRF903 */
          PWR_DWN(0);
          TXEN(0);
          CFG_CS(0);
          CFG_DATA(0);
          CFG_CLK(0);
          if(bChannel > nMaxChannel){
               bChannel = nMaxChannel;
               }
          wCfgData = wCfgData | (bChannel << 4);  /* Konfigdaten aufodern */
          vSendCfg(wCfgData);      /* nRF903 initialisieren */
          STBY(1);                 /* nRF903 im Standby-Mode */
          mcDisInt();              /* Interrupt sperren */
          fRxFunc = fRx;           /* Callback-Funktion zuweisen */
          bTxIndex = 0;            /* sicherheitshalber */
          mcEnaInt();
          STBY(0);
          PWR_DWN(0);
          TXEN(0);
          bRfState = enRfCheckCarrier;
          return True;
          }
     else return False;
     }

/***************************************************************************
*    Funktion: Kommunikationsinterface freigeben                           *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
bool RF4_boClose ( fCallBackRx fRx ){
     if(fRxFunc == fRx){
          mcDisInt();              /* Interrupt sperren */
          fRxFunc = vRxDummy;      /* Callback-Funktionen freigeben */
          IE1 &= ~(UTXIE0 + URXIE0);
          mcEnaInt();
          bRfState = enRfInit;
          return True;
          }
     else return False;
     }


/***************************************************************************
*    Funktion: bergibt eine Message und liefert den Status zurck         *
*                                                                          *                                                                          *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
enTxState RF4_enSendMessage( byte bSize, byte *pBuff ){
     if(enState == enTxReady){
          if(bSize == 0){
               return enTxError;   /* nicht erlaubt */
               }
          else {                   /* Senden vorbereiten */
               bTxIndex = bSize;
               pTxBuffer = pBuff;
               enState = enTxPending;
               return enState;     /* Vorbereitungsmode */
               }
          }
     else return enState;          /* Rckgabe Status */
     }

/***************************************************************************
*    Funktion: Main-Loop, Aufruf alle 2,5 ms                                *
*                                                                          *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void RF4_vMain( void ){
     switch(bRfState){
          default:
          case enRfInit:           /* tut nix */
               STBY(1);            /* Strom sparen */
               break;
          case enRfCheckCarrier:   /* Test auf Trger */
#ifdef RFTEST
               vRxLedOff();
               vTxLedOff();
#endif
               TXEN(0);            /* Empfangsmode */
               if(C_SENSE){        /* Ist ein Trger aktiv ? */
                    bRfState = enRfPrepareRx; /* Ja! */
                    }
               else {              /* Soll gesendet werden ? */
                    if(enState == enTxPending){ /* Ja ! */
                         TXEN(1);  /* Sender einschalten */
                         bRfState = enRfPrepareTx; /* Zustand weiterschalten */
                         enState = enTxBusy;
#ifdef RFTEST
                         vTxLedOn();
#endif
                         }
                    }
               break;
          case enRfPrepareRx:      /* Empfangsmode vorbereiten */
               if(C_SENSE){        /* ist der Trger immer noch vorhanden ? */
                    mcDisInt();
                    IE1 |= URXIE0; /* Rx-Interrupt freigeben */
                    mcEnaInt();
                    bRfState = enRfReceive;
#ifdef RFTEST
                    vRxLedOn();
#endif
                    }
               else {
                    bRfState = enRfCheckCarrier;
                    }
               break;
          case enRfReceive:        /* Empfangsmode */
               if(!C_SENSE){       /* wenn der Trger weg ist, abschalten */
                    mcDisInt();
                    IE1 &= ~URXIE0;/* Empfangsinterrupt sperren */
                    mcEnaInt();
                    bRfState = enRfCheckCarrier;
                    }
               break;
          case enRfPrepareTx:      /* Interrupt vorbereiten */
               mcDisInt();
               IE1 &= ~URXIE0;     /* Rx-Int. sperren */
               IE1 |= UTXIE0;      /* Tx-Int. freigeben */
               mcEnaInt();
               bRfState = enRfTransmit;
               bTxState = enTxSync;
               bSyncCount = nSyncTime;
               U0TXBUF = nSync;    /* Start x-ISR */
               bTimeout = 0;
               break;
          case enRfTransmit:       /* Senden */
               bTimeout++;
               if(bTimeout > nOneSecond){
                    enState = enTxTimeOut;
                    bRfState = enRfCheckCarrier;
                    TXEN(0);       /* Sender aus */
                    mcDisInt();
                    IE1 &= ~UTXIE0;/* Tx-Interrupt sperren */
                    mcEnaInt();
                    }
               break;
          }
     }


/***************************************************************************
*    Funktion: Sendeinterrupt                                              *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
#pragma interrupt_handler uart0_tx_isr:UART0TX_VECTOR
void uart0_tx_isr(void){
     switch(bTxState){
          case enTxSync:
               if(bSyncCount > 0){
                    U0TXBUF = nSync;
                    bSyncCount--;
                    }
               else {
                    U0TXBUF = nSyncEnd;     /* letztes Synczeichen senden */
                    bTxState = enTxSyncEnd;
                    }
               break;
          case enTxSyncEnd:
                    U0TXBUF = *pTxBuffer;    /* erstes Zeichen senden */
                    pTxBuffer++;
                    bTxIndex--;
                    bTxState = enTxMessage;
               break;
          case enTxMessage:
               if(bTxIndex > 0){             /* und fleiig weiter */
                    U0TXBUF = *pTxBuffer;
                    pTxBuffer++;
                    bTxIndex--;
                    }
               else {
                    U0TXBUF = nSync;         /* Dummy-Zeichen */
                    bTxState = enTxOff;
                    }
               break;
          case enTxOff:
                    IE1 &= ~UTXIE0;          /* Tx-Interrupt sperren */
                    TXEN(0);
                    bRfState = enRfCheckCarrier;
                    enState = enTxReady;     /* Sender wieder bereit */
               break;
          default:
               bTxState = enTxOff;
               break;
          }
     }


/***************************************************************************
*    Funktion: Empfangsinterrupt                                           *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
#pragma interrupt_handler uart0_rx_isr:UART0RX_VECTOR
void uart0_rx_isr(void){
     fRxFunc( U0RXBUF );
     }

/***************************************************************************
* EOF: TAST.C
****************************************************************************/

