/***************************************************************************
* Titel        : RFHI.H
*
* Description  : Headerfile fr nRF2401
*
* Environment  : Anpassung auf MSP430
*
* Responsible  : J. Altenburg
*
* Guidelines   :
*
* Revision List:
  --------------------------------------------------------------------------
  Date     | Author          | Change
  --------------------------------------------------------------------------
  19.05.03 |J. Altenburg     | Ersterstellung
  --------------------------------------------------------------------------
           |                 |
  --------------------------------------------------------------------------
****************************************************************************/
/*
* Check if information are already included
*/
#ifndef RF433_H
#define RF433_H


#define MCUTYPE     MSP430F149          /* Spezifiziert den MCU-Type */
// #define MCUTYPE     M16C26


/***************************************************************************
* HEADER-FILES (Only those that are needed in this file)                   *
****************************************************************************/
/* System-headerfiles */
#include "cdef.h"                       /* General definitions and types */

#if       MCUTYPE == MSP430F149
 #include "msp430x14x.h"

#elif     MCUTYPE == M16C26
 #include "trallala.h"

#endif

/* Foreign headerfiles */


/***************************************************************************
* Defines und Makros fr externen Zugriff                                  *
****************************************************************************/
#if       MCUTYPE == MSP430F149
 #define  PWR_DWN(x)     (P4OUT = (P4OUT & 0xfe) | (x << 0))     /* PWR_DWN */
 #define  STBY(x)        (P4OUT = (P4OUT & 0xfd) | (x << 1))     /* STBY */
 #define  TXEN(x)        (P4OUT = (P4OUT & 0xfb) | (x << 2))     /* TXEN */
 #define  CFG_DATA(x)    (P4OUT = (P4OUT & 0xf7) | (x << 3))
 #define  CFG_CLK(x)     (P4OUT = (P4OUT & 0xef) | (x << 4))
 #define  CFG_CS(x)      (P4OUT = (P4OUT & 0xdf) | (x << 5))
 #define  C_SENSE        (P4IN & 0x80)

#elif     MCUTYPE == M16C26
 #define  mcSetPwr(x)

#endif

#define RFTEST                     /* Testschalter */

/***************************************************************************
* Typedefs                                                                 *
****************************************************************************/
typedef void (* fCallBackRx)(      /* Callback-Funktion fr Empfangsroutine */
     byte );


typedef enum enTxState {           /* Zustand des Sendepuffers */
     enTxReady = 0,      /* Senden mglich */
     enTxPending,        /* es soll gesendet werden */
     enTxBusy,           /* Senden */
     enTxTimeOut,        /* Sendung konnte nicht abgesetzt werden */
     enTxError           /* Fehler */
     } enTxState;


/***************************************************************************
*    Funktionsprototypen                                                   *
****************************************************************************/
void RF4_vInit ( void );
void RF4_vMain ( void );
bool RF4_boOpen ( fCallBackRx, byte );
bool RF4_boClose ( fCallBackRx );
enTxState RF4_enSendMessage( byte, byte * );
void RF4_vClearState( void );

/*
* End of check if information are already included
*/
#endif                                  /* ifndef */


/***************************************************************************
* EOF: CMDI.H                                                              *
****************************************************************************/

