/***************************************************************************
* Titel        : SMD.C
*
* Description  : Ansteuerung fr zwei Schrittmotoren
*
* Environment  :
*
* Responsible  : J. Altenburg
*
* Guidelines   :
*
* Revision List:
  --------------------------------------------------------------------------
  Date     | Author          | Change
  --------------------------------------------------------------------------
  20.02.04 |J. Altenburg     | Ersterstellung
  --------------------------------------------------------------------------
           |                 |
  --------------------------------------------------------------------------
****************************************************************************/

/***************************************************************************
* HEADER-FILES (Only those that are needed in this file)                   *
****************************************************************************/
/* System-headerfiles */
#include "cdef.h"                      /* General definitions and types */

/* Own headerfiles */
#include "smd.h"

/* Foreign headerfiles */
#include <stdlib.h>

/***************************************************************************
*    Konstaten                                                             *
****************************************************************************/
/* Achtung: Halbschritt ist nicht implementiert */
const byte abHalfPattern[] = {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
const byte abFullPattern[] = {0x00, 0x02, 0x03, 0x01, 0x00, 0x02, 0x03, 0x01};

#define nTableSize       7              /* Gre der Bitmustertabelle */
#define nSmdMask         0x03
#define mcSetDriverL(x)  (P1OUT = (P1OUT & ~nSmdMask) | x)
#define mcSetDriverR(x)  (P2OUT = (P2OUT & ~nSmdMask) | x)
#define nRampSize        8
#define nSmdLowSpeed     50000          /* niedrige Geschwindigkeit */
#define nSmdHighSpeed    15000          /* Hchstgeschwindigkeit */

/***************************************************************************
*    Variablen                                                             *
****************************************************************************/
byte bSmdStateL; /*
* Description : Variable fr Zustandsautomat
*/

byte bSmdStateR; /*
* Description : Variable fr Zustandsautomat
*/

fCallBackSmd fSmdFuncL; /*
* Description : Callbackfunktion fr Benachrichtigung
*/

fCallBackSmd fSmdFuncR; /*
* Description : Callbackfunktion fr Benachrichtigung
*/

const byte *pBitMusterL; /*
* Description : Index auf Bitmuster
*/

const byte *pBitMusterR; /*
* Description : Index auf Bitmuster
*/

byte bRampL; /*
* Description : Index auf Rampe
*/

byte bRampR; /*
* Description : Index auf Rampe
*/

dword dwStepsL; /*
* Description : Schrittzahl
*/

dword dwStepsR; /*
* Description : Schrittzahl
*/

int8 i8DirL; /*
* Description : Decrement/Increment
*/

int8 i8DirR; /*
* Description : Decrement/Increment
*/

byte bSmdCountL; /*
* Description : Schrittzhler
*/

byte bSmdCountR; /*
* Description : Schrittzhler
*/

word awRampL[nRampSize]; /*
* Description : Beschleunigung/Bremsung
*/

word awRampR[nRampSize]; /*
* Description : Beschleunigung/Bremsung
*/

/* Zugriffsmakros fr Merkflags */



/**********************************************************************
* Defines und Makros Zugriff                                               *
****************************************************************************/
enum {
     enSmdInit = 0,                /* tut nix */
     enSmdPrep1,                   /* Start-Stop vorbereiten */
     enSmdPrep2,                   /* Normalmode vorbereiten */
     enSmdStartStop,               /* Start-Stop-Mode */
     enSmdRampUp,                  /* Beschleunigung */
     enSmdMove,                    /* Drehung */
     enSmdRampDown,                /* Bremsen */
     };

#define mcPowerOnL()       (P1OUT &= ~0xfc)
#define mcPowerOffL()      (P1OUT |=  0xd8)

#define mcPowerOnR()       (P2OUT &= ~0xfc)
#define mcPowerOffR()      (P2OUT |=  0xd8)


/***************************************************************************
*    Code                                                                  *
****************************************************************************/

/***************************************************************************
*    Funktion: Dummy fr Benachrichtigungsfunktion                         *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void vSmdDummy( void ){
      byte i;
      i++;        /* */
      }

/***************************************************************************
*    Funktion: Not-Aus, Motor wird sofort gestoppt                         *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void SMD_vCritical( void ){

     }

/***************************************************************************
*    Funktion: Initialisierung                                             *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void SMD_vInit( void ){
     fSmdFuncL = vSmdDummy;                   /* Callbackfunktion initialisieren */
     bSmdStateL = enSmdInit;
     fSmdFuncR = vSmdDummy;                   /* Callbackfunktion initialisieren */
     bSmdStateR = enSmdInit;
     }



/***************************************************************************
*    Funktion: Kommunikationsinterface zum Schrittmotortreiber             *
*              - Benachritigungsfunktion initialisieren                    *
*              - Bewegungsmode einstellen                                  *
*              - Hochlaufkurve berechnen                                   *
*              - Schrittzahl einstellen                                    *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void SMD_vStartL( fCallBackSmd fSmd,    /* Benachrichtigung */
                  byte bTyp,            /* Bewegungstyp, Halbschritt, Vollschritt */
                  word wMax,            /* Maximalgeschwindigkeit */
                  int32 iW              /* Schrittzahl, Vorzeichen = Drehrichtung */
                ){
     word w;
     byte i;     
     fSmdFuncL = fSmd;                   /* Benachrichtigungsfunktion */
     if(iW == 0){
           fSmdFuncL();
           return;                      /* Schrittzahl 0 abfangen */
           }
     if(iW >= 0){                       /* Drehrichtung festlegen */
          dwStepsL = iW;
          i8DirL = 1;
          }
     else {
          dwStepsL = abs(iW);
          i8DirL = -1;
          }
     if(bTyp){                          /* Unterscheidung Halb/Vollschritt */
          pBitMusterL = &abHalfPattern[0];
          }
     else {
          pBitMusterL = &abFullPattern[0];
          }
     /* Hochlauframpe berechnen */
     if(wMax < nSmdHighSpeed) wMax = nSmdHighSpeed; /* Maximalgeschwindigkeit begrenzen */
     if(wMax > (nSmdLowSpeed - nRampSize)){
          wMax = nSmdLowSpeed - nRampSize;
          }
     if(dwStepsL < (2 * nRampSize)){     /* nur Start-Stop Geschwindigkeit */
          awRampL[0] = nSmdLowSpeed;
          bSmdStateL = enSmdPrep1;       /* Bewegung vorbereiten */
          }
     else {
          w = nSmdLowSpeed - wMax;      /* Differenzgeschwindigkeit */
          w = w / nRampSize;            /* Geschwindigkeitsschritte */
          for(i = 0; i < nRampSize; i++){
               awRampL[i] = nSmdLowSpeed - w * (i + 1);
               }
          dwStepsL -= 2 * nRampSize;     /* Schritte mit Hchstgeschwindigkeit */
          bSmdStateL = enSmdPrep2;       /* Bewegung vorbereiten */
          }
     }


/***************************************************************************
*    Funktion: Interruptservive-Funktion zur Motorsteuerung                *
*                                                                          *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
word SMD_wMoveL ( void ){                    /* Bewegungserzeugung */
     byte i;
     word wTime;
     switch(bSmdStateL){
          case enSmdInit:                    /* tut nix */
               mcPowerOffL();                 /* Haltestrom einstellen */
               wTime = nSmdLowSpeed;         /* Zeitspanne bis zum nchsten Aufruf */
               break;
          case enSmdPrep1:                   /* Start-Stop vorbereiten */
               mcPowerOnL();
               wTime = awRampL[0];            /* Zeit aus Rampentabelle */
               bSmdStateL = enSmdStartStop;
               break;
          case enSmdPrep2:                   /* Normalmode vorbereiten */
               mcPowerOnL();
               wTime = awRampL[0];
               bRampL = 0;
               bSmdStateL = enSmdRampUp;
               break;
          case enSmdStartStop:               /* Start-Stop-Mode */
               i = bSmdCountL & nTableSize;   /* Offset fr Zeiger auf Tabelle begrenzen */
               mcSetDriverL(*(pBitMusterL+i));
               bSmdCountL += i8DirL;           /* nchster Schritt */
               dwStepsL--;
               if(dwStepsL == 0){
                      bSmdStateL = enSmdInit;
                      fSmdFuncL();
                      }
               wTime = awRampL[0];            /* Schrittzeit */
               break;
          case enSmdRampUp:                  /* Beschleunigung */
               i = bSmdCountL & nTableSize;   /* Zeiger auf Bitmuster berechnen */
               mcSetDriverL(*(pBitMusterL+i));
               bSmdCountL += i8DirL;           /* nchster Schritt */
               bRampL++;
               wTime = awRampL[bRampL];
               if(bRampL >= nRampSize - 1) bSmdStateL = enSmdMove;
               break;
          case enSmdMove:                    /* Drehung */
               i = bSmdCountL & nTableSize;   /* Zeiger auf Bitmuster berechnen */
               mcSetDriverL(*(pBitMusterL+i));
               bSmdCountL += i8DirL;           /* nchster Schritt */
               dwStepsL--;
               if(dwStepsL == 0) bSmdStateL = enSmdRampDown;
               wTime = awRampL[nRampSize - 1];
               break;
          case enSmdRampDown:                /* Bremsen */
               i = bSmdCountL & nTableSize;   /* Zeiger auf Bitmuster berechnen */
               mcSetDriverL(*(pBitMusterL+i));
               bSmdCountL += i8DirL;           /* nchster Schritt */
               bRampL--;
               wTime = awRampL[bRampL];
               if(bRampL == 0){
                    bSmdStateL = enSmdInit;
                    fSmdFuncL();              /* Motorbewegung ist beendet */
                    }
               break;
          }
     return wTime;
     }



/***************************************************************************
*    Funktion: Kommunikationsinterface zum Schrittmotortreiber             *
*              - Benachritigungsfunktion initialisieren                    *
*              - Bewegungsmode einstellen                                  *
*              - Hochlaufkurve berechnen                                   *
*              - Schrittzahl einstellen                                    *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
void SMD_vStartR( fCallBackSmd fSmd,    /* Benachrichtigung */
                  byte bTyp,            /* Bewegungstyp, Halbschritt, Vollschritt */
                  word wMax,            /* Maximalgeschwindigkeit */
                  int32 iW              /* Schrittzahl, Vorzeichen = Drehrichtung */
                ){
     word w;
     byte i;
     fSmdFuncR = fSmd;
     if(iW == 0){
           fSmdFuncR();
           return;                      /* Schrittzahl 0 abfangen */
           }
     if(iW >= 0){                       /* Drehrichtung festlegen */
          dwStepsR = iW;
          i8DirR = 1;
          }
     else {
          dwStepsR = abs(iW);
          i8DirR = -1;
          }
     if(bTyp){                          /* Unterscheidung Halb/Vollschritt */
          pBitMusterR = &abHalfPattern[0];
          }
     else {
          pBitMusterR = &abFullPattern[0];
          }
     /* Hochlauframpe berechnen */
     if(wMax < nSmdHighSpeed) wMax = nSmdHighSpeed; /* Maximalgeschwindigkeit begrenzen */
     if(wMax > (nSmdLowSpeed - nRampSize)){
          wMax = nSmdLowSpeed - nRampSize;
          }
     if(dwStepsR < (2 * nRampSize)){     /* nur Start-Stop Geschwindigkeit */
          awRampR[0] = nSmdLowSpeed;
          bSmdStateR = enSmdPrep1;       /* Bewegung vorbereiten */
          }
     else {
          w = nSmdLowSpeed - wMax;      /* Differenzgeschwindigkeit */
          w = w / nRampSize;            /* Geschwindigkeitsschritte */
          for(i = 0; i < nRampSize; i++){
               awRampR[i] = nSmdLowSpeed - w * (i + 1);
               }
          dwStepsR -= 2 * nRampSize;     /* Schritte mit Hchstgeschwindigkeit */
          bSmdStateR = enSmdPrep2;       /* Bewegung vorbereiten */
          }
     }


/***************************************************************************
*    Funktion: Interruptservive-Funktion zur Motorsteuerung                *
*                                                                          *
*    Autor:    Jens Altenburg                                              *
****************************************************************************/
word SMD_wMoveR ( void ){                    /* Bewegungserzeugung */
     byte i;
     word wTime;
     switch(bSmdStateR){
          case enSmdInit:                    /* tut nix */
               mcPowerOffR();                 /* Haltestrom einstellen */
               wTime = nSmdLowSpeed;         /* Zeitspanne bis zum nchsten Aufruf */
               break;
          case enSmdPrep1:                   /* Start-Stop vorbereiten */
               mcPowerOnR();
               wTime = awRampR[0];            /* Zeit aus Rampentabelle */
               bSmdStateR = enSmdStartStop;
               break;
          case enSmdPrep2:                   /* Normalmode vorbereiten */
               mcPowerOnR();
               wTime = awRampR[0];
               bRampR = 0;
               bSmdStateR = enSmdRampUp;
               break;
          case enSmdStartStop:               /* Start-Stop-Mode */
               i = bSmdCountR & nTableSize;   /* Offset fr Zeiger auf Tabelle begrenzen */
               mcSetDriverR(*(pBitMusterR+i));
               bSmdCountR += i8DirR;           /* nchster Schritt */
               dwStepsR--;
               if(dwStepsR == 0){
                      bSmdStateR = enSmdInit;
                      fSmdFuncR();
                      }
               wTime = awRampR[0];            /* Schrittzeit */
               break;
          case enSmdRampUp:                  /* Beschleunigung */
               i = bSmdCountR & nTableSize;   /* Zeiger auf Bitmuster berechnen */
               mcSetDriverR(*(pBitMusterR+i));
               bSmdCountR += i8DirR;           /* nchster Schritt */
               bRampR++;
               wTime = awRampR[bRampR];
               if(bRampR >= nRampSize - 1) bSmdStateR = enSmdMove;
               break;
          case enSmdMove:                    /* Drehung */
               i = bSmdCountR & nTableSize;   /* Zeiger auf Bitmuster berechnen */
               mcSetDriverR(*(pBitMusterR+i));
               bSmdCountR += i8DirR;           /* nchster Schritt */
               dwStepsR--;
               if(dwStepsR == 0) bSmdStateR = enSmdRampDown;
               wTime = awRampR[nRampSize - 1];
               break;
          case enSmdRampDown:                /* Bremsen */
               i = bSmdCountR & nTableSize;   /* Zeiger auf Bitmuster berechnen */
               mcSetDriverR(*(pBitMusterR+i));
               bSmdCountR += i8DirR;           /* nchster Schritt */
               bRampR--;
               wTime = awRampR[bRampR];
               if(bRampR == 0){
                    bSmdStateR = enSmdInit;
                    fSmdFuncR();              /* Motorbewegung ist beendet */
                    }
               break;
          }
     return wTime;
     }
     
     
/***************************************************************************
* EOF: SMD.C
****************************************************************************/

