/***************************************************************************
* Titel        : UEXC.H
*
* Description  : Multitasking Kernel Module 
*
* Environment  : ICC430 V6.05, MSP430F149
*
* Responsible  : Richrad F. Man
*
* Guidelines   :
*
* Revision List:
  --------------------------------------------------------------------------
  Date     | Author          | Change
  --------------------------------------------------------------------------
  12.02.04 |J. Altenburg     | fits to MSP430 
  --------------------------------------------------------------------------
           |                 |
  --------------------------------------------------------------------------
****************************************************************************/
#ifndef _UEXEC_H
#define _UEXEC_H


/***************************************************************************
*    Function Prototypes
****************************************************************************/
int UEXC_CreateTask	         ( void (*func)(void),
                    		   unsigned char *stack_start,
                    		   unsigned stack_size,
                    		   unsigned ticks);
void UEXC_Defer        		 ( void );
void UEXC_HogProcessor 		 ( void );
void UEXC_KillTask     		 ( int pid );
void UEXC_CheckTask    		 ( void ); 
void UEXC_KillSelf	   		 ( void ); 
void UEXC_Schedule	   		 ( void ); 
int  UEXC_StartScheduler	 ( void );
void UEXC_Resume			 ( void );
void UEXC_StartTimer		 ( void );
void UEXC_SavregsAndResched	 ( void );
void UEXC_StartNewTask		 ( void );
void UEXC_CheckTask			 ( void );


/***************************************************************************
*   External Variables
****************************************************************************/
extern unsigned char *uexc_current_sp;
extern void (*uexc_current_func)(void);

/* Minimum stack size for a task function that does not use "any" stack space.
 * This should be the interrupt stack frame, plus some fudge factor for
 * frame pointer, a single function call, etc. */
#define UEXC_MIN_STACK_SIZE (100)       /* minimale stack size */
#define INTR_ON()           asm("eint")
#define INTR_OFF()          asm("dint")

/* Number of tasks, change this to suit your need */
#define NUM_TASKS           4           
/* default time ticks */
#define DEFAULT_TICKS       5


/* Task State: no need to declare T_CURRENT */
enum { T_CREATED, T_READY };

typedef struct TaskControlBlock {
    struct  TaskControlBlock *next;
    unsigned char tid;          /* task id */
    unsigned char state;        /* task state, do not use enum
                                 * since the compiler may allocate
                                 * more space */
    unsigned char ticks;        /* how many ticks does the task execute */
    unsigned char current_ticks;/* current number of ticks remaining */
    void    (*func)(void);      /* function to call for that task */
    unsigned char   *stack_start;       /* stack low value */
    unsigned char   *stack_end;         /* stack high value */
    unsigned char   *sp;        /* current value of the stack pointer */
    } TaskControlBlock;

#endif
